#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-3khSgGDdekrCx59hhRkN7p
key:                  hspec-hedgehog-0.0.1.2-3khSgGDdekrCx59hhRkN7p
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  4028cde092cd5955e6a597b4b2e1c16d
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-3khSgGDdekrCx59hhRkN7p
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-KKpj9xjK5s16FHurgbycnn base-4.18.2.1
    hedgehog-1.5-KQIv82UctR28hg4CuxxXE0
    hspec-2.11.6-BbEEg2y8GOLI4Xv79thZsm
    hspec-core-2.11.6-o7pOqdhoWvC86f6BvoECv
    splitmix-0.1.3-JgFjpGLPSHgEaXyaSqc9cB

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

